;;;; -*- Mode: LISP; Syntax: ANSI-Common-Lisp; Base: 10 -*-

;;;; *************************************************************************
;;;; FILE IDENTIFICATION
;;;;
;;;; Name:          specials.lisp
;;;; Purpose:       cl-digg specials informations.
;;;; Programmer:    Nicolas Lamirault <nicolas.lamirault@gmail.com>
;;;;
;;;; This file, part of cl-digg, is Copyright (c) 2007 by Nicolas Lamirault
;;;;
;;;; cl-digg users are granted the rights to distribute and use this software
;;;; as governed by the terms of the Lisp Lesser GNU Public License
;;;; (http://opensource.franz.com/preamble.html), also known as the LLGPL.
;;;;
;;;; *************************************************************************


(in-package :cl-digg)


(defparameter *debug* nil
  "When T, active more informations about Digg requests.")


(defparameter *api-key* "http://perave.dyndns.org/projects/cl-digg"
  "The value of the appkey argument must be a valid absolute URI
(see IETF RFC 2396) that identifies the application making the request.
The URI might point to:
    * The application itself, if it's a web application.
    * A web page describing the application.
    * A web page offering the application for download.
    * The author's web site.")


(defparameter *digg-server* "http://services.digg.com"
  "The Digg web service server.")


(defparameter *list-error-codes* "/errors"
  "URI to fetches API error codes and messages.")


(defparameter *get-error-code* "/error/"
  "URI to get the message for a specific error code.")


(defparameter *list-events* "/events"
  "URI to fetches a list of diggs or comments from Digg.")


(defparameter *list-stories* "/stories"
  "URI to fetches a list of stories from Digg.")


(defparameter *list-topics* "/topics"
  "URI to fetches a list of topics from Digg.")


(defparameter *list-users* "/users"
  "URI to fetches a list of users from Digg.")


(defparameter *get-user* "/user/"
  "URI to fetches details of a Digg user.")


(defparameter *list-user-friends* "/user/~A/friends"
  "URI to fetches user's friends.")


(defparameter *get-user-friend* "/user/~A/friend/"
  "URI to fetches user's friend informations.")


(defparameter *list-user-fans* "/user/~A/fans"
  "URI to fetches user's fans.")


(defparameter *get-user-fan* "/user/~A/fan/"
  "URI to fetches user's fan informations.")


(defparameter *list-topics* "/topics"
  "URI to fetches a list of topics from Digg.")


(defparameter *get-topic* "/topic/"
  "URI to fetches details of a Digg topic.")


(defparameter *get-stories* "/stories"
  "URI to fetches all stories.")


(defparameter *get-popular-stories* "/stories/popular"
  "URI to fetches popular stories.")


(defparameter *get-upcoming-stories* "/stories/upcoming"
  "URI to fetches upcoming stories.")


(defparameter *get-container-stories* "/stories/container/"
  "URI to fetches all stories from a given container.")


(defparameter *get-popular-container-stories* "/stories/container/~A/popular"
  "URI to fetches popular stories from a given container.")


(defparameter *get-upcoming-container-stories* "/stories/container/~A/upcoming"
  "URI to fetches upcoming stories from a given container.")


(defparameter *get-topic-stories* "/stories/topic/"
  "URI to fetches all stories from a given topic.")


(defparameter *get-popular-topic-stories* "/stories/topic/~A/popular"
  "URI to fetches popular stories from a given topic.")


(defparameter *get-upcoming-topic-stories* "/stories/topic/~A/upcoming"
  "URI to fetches upcoming stories from a given topic.")


(defparameter *get-story* "/story/"
  "URI to fetches an identified story.")


(defparameter *get-some-stories* "/stories/"
  "URI to fetches a list of stories with the given ids.")


(defparameter *get-user-stories* "/user/~A/submissions"
  "URI to fetches stories submitted by given user.")


(defparameter *diggs* "/stories/diggs"
  "URL to fetches all digs.")


(defparameter *popular-diggs* "/stories/popular/diggs"
  "URL to fetches all diggs on popular stories.")


(defparameter *upcoming-diggs* "/stories/upcoming/diggs"
  "URL to fectches all diggs on upcoming stories.")


(defparameter *stories-diggs* "/stories/~{~A~^,~}/diggs"
  "URL to fetches all diggs for a list of stories with the given ids.")


(defparameter *story-diggs* "/story/~A/diggs"
  "URL to fetches all diggs for a given story.")


(defparameter *user-diggs* "/user/~A/diggs"
  "URL to fetches all user's diggs for all stories.")


(defparameter *users-diggs* "/users/~{~A~^,~}/diggs"
  "URL to fetches several users' diggs for all stories")


(defparameter *user-digg* "/story/~A/user/~A/digg"
  "URL to fetches one user digg for a given story.")


(defparameter *comments* "/stories/comments"
  "URL to fetches all comments.")


(defparameter *popular-comments* "/stories/popular/comments"
  "URL to fetches all comments on popular stories.")


(defparameter *upcoming-comments* "/stories/upcoming/comments"
  "URL to fetches all comments on upcoming stories.")


(defparameter *stories-comments* "/stories/~{~A~^,~}/comments"
  "URL to fetches all comments for a list of stories with the given ids.")


(defparameter *story-comments* "/story/~A/comments"
  "URL to fetches top-level comments for a given story")


(defparameter *user-comments* "/user/~A/comments"
  "URL to fetches one user's comments for all stories.")


(defparameter *users-comments* "/users/~{~A~^,~}/comments"
  "URL to fetches several users' comments for all stories.")


(defparameter *story-comment* "/story/~A/comment/~A"
  "URL to fetches one comment for a given story.")


(defparameter *story-comment-replies* "/story/~A/comment/~A/replies"
  "URL to fetches one level of replies to one comment for a given story")