;;;; -*- Mode: LISP; Syntax: ANSI-Common-Lisp; Base: 10 -*-

;;;; *************************************************************************
;;;; FILE IDENTIFICATION
;;;;
;;;; Name:          test-users.lisp
;;;; Purpose:       Unit Tests for the Users API.
;;;; Programmer:    Nicolas Lamirault <nicolas.lamirault@gmail.com>
;;;;
;;;; This file, part of cl-digg, is Copyright (c) 2007 by Nicolas Lamirault
;;;;
;;;; cl-digg users are granted the rights to distribute and use this software
;;;; as governed by the terms of the Lisp Lesser GNU Public License
;;;; (http://opensource.franz.com/preamble.html), also known as the LLGPL.
;;;;
;;;; *************************************************************************


(in-package :cl-digg-test)


(lisp-unit:define-test get-all-users
  (let ((sum 0))
    (cl-ppcre:do-matches (s e "<user name=" (cl-digg:get-users))
      (incf sum))
    (lisp-unit:assert-equal sum 10)))


(lisp-unit:define-test get-some-users
  (let* ((sum 0))
    (cl-ppcre:do-matches (s e "<user name=" (cl-digg:get-users :count 20))
      (incf sum))
    (lisp-unit:assert-equal sum 20)))


(lisp-unit:define-test get-unknown-user
  (let ((name (format nil "~A" (gensym))))
    (lisp-unit:assert-error 'cl-digg:digg-request-error
                            (cl-digg:get-users :user-name name))))


(unless (boundp '+digg-user-test+)
  (defconstant +digg-user-test+ "kevinrose"
    "See http://digg.com/about/kevin."))


(lisp-unit:define-test get-user
  (let ((sum 0))
    (cl-ppcre:do-matches (s e "<user name="
                            (cl-digg:get-users :user-name +digg-user-test+))
      (incf sum))
    (lisp-unit:assert-equal sum 1)))


(lisp-unit:define-test get-all-user-friends
  (let ((sum 0))
    (cl-ppcre:do-matches (s e "<user name="
                            (cl-digg:get-user-friends +digg-user-test+))
      (incf sum))
    (lisp-unit:assert-equal sum 10)))


(lisp-unit:define-test get-some-user-friends
  (let ((sum 0))
    (cl-ppcre:do-matches (s e "<user name="
                            (cl-digg:get-user-friends +digg-user-test+ :count 20))
      (incf sum))
    (lisp-unit:assert-equal sum 20)))


(lisp-unit:define-test get-unknown-user-friend
  (let ((friend (format nil "~A" (gensym))))
    (lisp-unit:assert-error
     'cl-digg:digg-request-error
     (cl-digg:get-user-friends +digg-user-test+ :friend-name friend))))


(lisp-unit:define-test get-user-friend
  (let* ((data (cl-digg:get-user-friends +digg-user-test+ :count 1))
         friend)
    (cl-ppcre:do-matches (s e "<user name=" data)
      (setf friend
            (format nil "~A"
                    (subseq data (1+ e) (- (search "icon" data) 2)))))
    (lisp-unit:assert-true friend)
    (let ((sum 0))
      (cl-ppcre:do-matches (s e "<user name="
                              (cl-digg:get-user-friends +digg-user-test+ :friend-name friend))
        (incf sum))
      (lisp-unit:assert-equal sum 1))))


(lisp-unit:define-test get-all-user-fans
  (let ((sum 0))
    (cl-ppcre:do-matches (s e "<user name="
                            (cl-digg:get-user-fans +digg-user-test+))
      (incf sum))
    (lisp-unit:assert-equal sum 10)))


(lisp-unit:define-test get-some-user-fans
  (let ((sum 0))
    (cl-ppcre:do-matches (s e "<user name="
                            (cl-digg:get-user-fans +digg-user-test+ :count 20))
      (incf sum))
    (lisp-unit:assert-equal sum 20)))


(lisp-unit:define-test get-unknown-user-fan
  (let ((fan (format nil "~A" (gensym))))
    (lisp-unit:assert-error
     'cl-digg:digg-request-error
     (cl-digg:get-user-fans +digg-user-test+ :fan-name fan))))

    
(lisp-unit:define-test get-user-fan
  (let* ((data (cl-digg:get-user-fans +digg-user-test+ :count 1))
         fan)
    (cl-ppcre:do-matches (s e "<user name=" data)
      (setf fan
            (format nil "~A"
                    (subseq data (1+ e) (- (search "icon" data) 2)))))
    (lisp-unit:assert-true fan)
    (let ((sum 0))
      (cl-ppcre:do-matches (s e "<user name="
                              (cl-digg:get-user-fans +digg-user-test+ :fan-name fan))
        (incf sum))
      (lisp-unit:assert-equal sum 1))))


    

